==> druid-server-0.22.1-sources.jar: org/apache/druid/server/metrics/TaskSlotCountStatsProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.server.metrics;

import javax.annotation.Nullable;

public interface TaskSlotCountStatsProvider
{
  /**
   * Return the number of total task slots during emission period.
   */
  @Nullable
  Long getTotalTaskSlotCount();

  /**
   * Return the number of idle task slots during emission period.
   */
  @Nullable
  Long getIdleTaskSlotCount();

  /**
   * Return the number of used task slots during emission period.
   */
  @Nullable
  Long getUsedTaskSlotCount();

  /**
   * Return the total number of task slots in lazy marked middlemanagers and indexers during emission period.
   */
  @Nullable
  Long getLazyTaskSlotCount();

  /**
   * Return the total number of task slots in blacklisted middlemanagers and indexers during emission period.
   */
  @Nullable
  Long getBlacklistedTaskSlotCount();
}

==> druid-server-24.0.2-sources.jar: org/apache/druid/server/metrics/TaskSlotCountStatsProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.server.metrics;

import javax.annotation.Nullable;

import java.util.Map;

public interface TaskSlotCountStatsProvider
{
  /**
   * Return the number of total task slots during emission period.
   */
  @Nullable
  Map<String, Long> getTotalTaskSlotCount();

  /**
   * Return the number of idle task slots during emission period.
   */
  @Nullable
  Map<String, Long> getIdleTaskSlotCount();

  /**
   * Return the number of used task slots during emission period.
   */
  @Nullable
  Map<String, Long> getUsedTaskSlotCount();

  /**
   * Return the total number of task slots in lazy marked middlemanagers and indexers during emission period.
   */
  @Nullable
  Map<String, Long> getLazyTaskSlotCount();

  /**
   * Return the total number of task slots in blacklisted middlemanagers and indexers during emission period.
   */
  @Nullable
  Map<String, Long> getBlacklistedTaskSlotCount();
}
